==> kxdocker_0.26.orig.tar.gz: kxdocker-0.26.orig/src/kxdocker_setup_sources.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano                                         *
 *   stefano@xiaprojects.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
 
// by default 0.26 support threading
// to enable GPipe plugin 15Gen2005
// #define QT_THREAD_SUPPORT

// enable interpolation engine
#define ENABLE_SPECIALENGINE2
 
// this will disable debug messages and a lot of tests!!!
#define ENABLE_FINAL

==> kxdocker_0.35.orig.tar.gz: kxdocker-0.35.orig/src/kxdocker_setup_sources.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano                                         *
 *   stefano@xiaprojects.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
// 0.33
#define KXDOCKERVERSION		"0.0.35"
#define KXDOCKERNEED		"0.0.12"
#define KXDOCKERDATE		"20050702"
#define KXDOCKERHEADERVERSION	"0.0.35"

 
// by default 0.26 support threading
// to enable GPipe plugin 15Gen2005
// #define QT_THREAD_SUPPORT

// enable interpolation engine
#define ENABLE_SPECIALENGINE2
 
// this will disable debug messages and a lot of tests!!!
#define ENABLE_FINAL
